@@ -149,5 +149,11 @@ class DrawingLeaders(Collection):
         """
         return self.drawing_leaders.Remove(i_index)
 
+    def __getitem__(self, n: int) -> DrawingLeader:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return DrawingLeader(self.drawing_leaders.item(n + 1))
+
     def __repr__(self):
         return f'DrawingLeaders(name="{self.name}")'
