@@ -171,5 +171,11 @@ class DrawingTables(Collection):
         """
         return self.drawing_tables.Remove(i_index)
 
+    def __getitem__(self, n: int) -> DrawingTable:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return DrawingTable(self.drawing_tables.item(n + 1))
+
     def __repr__(self):
         return f'DrawingTables(name="{self.name}")'
