@@ -155,5 +155,11 @@ class DrawingWeldings(Collection):
         """
         return self.drawing_weldings.Remove(i_index)
 
+    def __getitem__(self, n: int) -> DrawingWelding:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return DrawingWelding(self.drawing_weldings.item(n + 1))
+
     def __repr__(self):
         return f'DrawingWeldings(name="{self.name}")'
