@@ -628,5 +628,11 @@ class Relations(Collection):
         """
         return Relations(self.relations.SubList(i_feature.com_object, i_recursively))
 
+    def __getitem__(self, n: int) -> Relation:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return Relation(self.relations.item(n + 1))
+
     def __repr__(self):
         return f'Relations(name="{self.name}")'
