@@ -72,5 +72,11 @@ class Units(Collection):
         """
         return Unit(self.units.Item(i_index))
 
+    def __getitem__(self, n: int) -> Unit:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return Unit(self.units.item(n + 1))
+
     def __repr__(self):
         return f'Units(name="{self.name}")'
