@@ -107,5 +107,11 @@ class HybridBodies(Collection):
         except com_error:
             raise CATIAApplicationException(f'Could not find hybrid_body "i_index"')
 
+    def __getitem__(self, n: int) -> HybridBody:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return HybridBody(self.hybrid_bodies.item(n + 1))
+
     def __repr__(self):
         return f'HybridBodies(name="{self.name}")'
